@@ -60,7 +60,7 @@ data EmailCreds m = EmailCreds
     , emailCredsVerkey :: Maybe VerKey
     }
 
-class (YesodAuth m, SinglePiece (AuthEmailId m)) => YesodAuthEmail m where
+class (YesodAuth m, PathPiece (AuthEmailId m)) => YesodAuthEmail m where
     type AuthEmailId m
 
     addUnverified :: Email -> VerKey -> GHandler Auth m (AuthEmailId m)
@@ -102,7 +102,7 @@ authEmail =
     dispatch "GET" ["register"] = getRegisterR >>= sendResponse
     dispatch "POST" ["register"] = postRegisterR >>= sendResponse
     dispatch "GET" ["verify", eid, verkey] =
-        case fromSinglePiece eid of
+        case fromPathPiece eid of
             Nothing -> notFound
             Just eid' -> getVerifyR eid' verkey >>= sendResponse
     dispatch "POST" ["login"] = postLoginR >>= sendResponse
@@ -142,7 +142,7 @@ postRegisterR = do
                 return (lid, key)
     render <- getUrlRender
     tm <- getRouteToMaster
-    let verUrl = render $ tm $ verify (toSinglePiece lid) verKey
+    let verUrl = render $ tm $ verify (toPathPiece lid) verKey
     sendVerifyEmail email verKey verUrl
     defaultLayout $ do
         setTitleI Msg.ConfirmationEmailSentTitle
@@ -163,7 +163,7 @@ getVerifyR lid key = do
                     setCreds False $ Creds "email" email [("verifiedEmail", email)] -- FIXME uid?
                     toMaster <- getRouteToMaster
                     setMessageI Msg.AddressVerified
-                    redirect RedirectTemporary $ toMaster setpassR
+                    redirect $ toMaster setpassR
         _ -> return ()
     defaultLayout $ do
         setTitleI Msg.InvalidKey
@@ -193,7 +193,7 @@ postLoginR = do
         Nothing -> do
             setMessageI Msg.InvalidEmailPass
             toMaster <- getRouteToMaster
-            redirect RedirectTemporary $ toMaster LoginR
+            redirect $ toMaster LoginR
 
 getPasswordR :: YesodAuthEmail master => GHandler Auth master RepHtml
 getPasswordR = do
@@ -203,7 +203,7 @@ getPasswordR = do
         Just _ -> return ()
         Nothing -> do
             setMessageI Msg.BadSetPass
-            redirect RedirectTemporary $ toMaster loginR
+            redirect $ toMaster LoginR
     defaultLayout $ do
         setTitleI Msg.SetPassTitle
         addWidget
@@ -233,17 +233,17 @@ postPasswordR = do
     y <- getYesod
     when (new /= confirm) $ do
         setMessageI Msg.PassMismatch
-        redirect RedirectTemporary $ toMaster setpassR
+        redirect $ toMaster setpassR
     maid <- maybeAuthId
     aid <- case maid of
             Nothing -> do
                 setMessageI Msg.BadSetPass
-                redirect RedirectTemporary $ toMaster loginR
+                redirect $ toMaster LoginR
             Just aid -> return aid
     salted <- liftIO $ saltPass new
     setPassword aid salted
     setMessageI Msg.PassUpdated
-    redirect RedirectTemporary $ loginDest y
+    redirect $ loginDest y
 
 saltLength :: Int
 saltLength = 5
