@@ -11,7 +11,6 @@ module Yesod.Auth.OpenId
 
 import Yesod.Auth
 import qualified Web.Authenticate.OpenId as OpenId
-import Control.Monad.Attempt
 
 import Yesod.Form
 import Yesod.Handler
@@ -19,9 +18,9 @@ import Yesod.Widget
 import Yesod.Request
 import Text.Cassius (cassius)
 import Text.Blaze (toHtml)
-import Control.Monad.Trans.Class (lift)
 import Data.Text (Text)
 import qualified Yesod.Auth.Message as Msg
+import Control.Exception.Lifted (SomeException, try)
 
 forwardUrl :: AuthRoute
 forwardUrl = PluginR "openid" ["forward"]
@@ -61,18 +60,17 @@ authOpenIdExtended extensionFields =
                 render <- getUrlRender
                 toMaster <- getRouteToMaster
                 let complete' = render $ toMaster complete
-                res <- runAttemptT $ OpenId.getForwardUrl oid complete' Nothing extensionFields 
-                attempt
-                  (\err -> do
-                        setMessage $ toHtml $ show err
-                        redirect RedirectTemporary $ toMaster LoginR
-                        )
-                  (redirectText RedirectTemporary)
-                  res
+                master <- getYesod
+                eres <- lift $ try $ OpenId.getForwardUrl oid complete' Nothing extensionFields (authHttpManager master)
+                case eres of
+                    Left err -> do
+                        setMessage $ toHtml $ show (err :: SomeException)
+                        redirect $ toMaster LoginR
+                    Right x -> redirect x
             Nothing -> do
                 toMaster <- getRouteToMaster
                 setMessageI Msg.NoOpenID
-                redirect RedirectTemporary $ toMaster LoginR
+                redirect $ toMaster LoginR
     dispatch "GET" ["complete", ""] = dispatch "GET" ["complete"] -- compatibility issues
     dispatch "GET" ["complete"] = do
         rr <- getRequest
@@ -85,11 +83,12 @@ authOpenIdExtended extensionFields =
 
 completeHelper :: YesodAuth m => [(Text, Text)] -> GHandler Auth m ()
 completeHelper gets' = do
-        res <- runAttemptT $ OpenId.authenticate gets'
+        master <- getYesod
+        eres <- lift $ try $ OpenId.authenticate gets' (authHttpManager master)
         toMaster <- getRouteToMaster
         let onFailure err = do
-            setMessage $ toHtml $ show err
-            redirect RedirectTemporary $ toMaster LoginR
+            setMessage $ toHtml $ show (err :: SomeException)
+            redirect $ toMaster LoginR
         let onSuccess (OpenId.Identifier ident, _) =
                 setCreds True $ Creds "openid" ident gets'
-        attempt onFailure onSuccess res
+        either onFailure onSuccess eres
